package App::remotediff;

use strict;
use warnings;

our $VERSION = '1.16';

=head1 NAME

App::remotediff - remote diff over rsync

=head1 DESCRIPTION

This is a stub module, see F<script/remotediff>.

=cut

1;


1; # End of App::remotediff
